# aeneas Main Library 

This Python package contains the main ``aeneas`` library.

Wrappers for the built-in TTS engines are located
in the ``aeneas.ttswrappers`` subpackage.

The ``aeneas.tools`` subpackage define several command line tools
which use the main ``aeneas`` library.

Unit tests are contained in the ``aeneas.tests`` subpackage.

